==> najvaflutter-1.2.1.tar.gz: android/src/main/java/com/najva/najvaflutter/NajvaflutterPlugin.java <==
package com.najva.najvaflutter;

import android.content.Context;
import android.content.IntentFilter;
import android.support.annotation.NonNull;

import com.najva.sdk.Najva;
import com.najva.sdk.NajvaJsonDataListener;
import com.najva.sdk.UserSubscriptionListener;


import java.util.Map;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry;

/**
 * NajvaflutterpluginPlugin
 * created by shayan
 * flutter plugin for implement all features of najva android sdk in flutter
 **/
public class NajvaflutterPlugin implements MethodCallHandler,
        NajvaPluginUserHandler.INajvaPluginUserHandler,
        NajvaNotificationReceiver.OnNotificationReceiveListener,
        NajvaNotificationClickReceiver.OnNotificationClickListener{

    /**
     * final variables used for method names
     */
    private static final String INIT = "init";
    private static final String GET_SUBSCRIBED_TOKEN = "get_subscribed_token";

    /**
     * final variables for dart method names
     */
    private static final String NEW_JSON_DATA = "onNewJSONData";
    private static final String NEW_USER_SUBSCRIBED = " onUserSubscribed";
    private static final String NEW_NOTIFICATION_RECEIVED = "onNotificationReceived";
    private static final String NEW_NOTIFICATION_CLICKED = "onNotificationClicked";

    /**
     * Plugin registration.
     */
    public static void registerWith(PluginRegistry.Registrar registrar) {
        final MethodChannel channel = new MethodChannel(registrar.messenger(), "najvaFlutterplugin");
        channel.setMethodCallHandler(new NajvaflutterPlugin(channel,registrar.context()));

    }

    /* class implementation */

    private MethodChannel channel;
    private Context context;


    private NajvaflutterPlugin(MethodChannel channel, Context context) {
        this.channel = channel;
        this.context = context;
    }


    @Override
    public void onMethodCall(MethodCall call, @NonNull Result result) {
        switch (call.method) {
            case INIT:
                result.success(init());
                break;
            case GET_SUBSCRIBED_TOKEN:
                result.success(getSubscribedToken());
                break;
            default:
                result.notImplemented();
                break;
        }
    }

    private void handleUsersToken() {
        initUserHandler(new NajvaPluginUserHandler(this));
    }

    private void handleJSONNotification() {
        Najva.setNajvaJsonDataListener(new NajvaJsonDataListener() {
            @Override
            public void onReceiveJson(String s) {
                onJSONDataReceived(s);
            }
        });
    }

    private void initUserHandler(UserSubscriptionListener handler) {
        Najva.setUserSubscriptionListener(handler);
    }

    private boolean init() {

        Najva.initialize(context);
        handleJSONNotification();
        handleUsersToken();
        NajvaNotificationReceiver notificationReceiver = new NajvaNotificationReceiver(this);
        NajvaNotificationClickReceiver clickReceiver = new NajvaNotificationClickReceiver(this);
        context.registerReceiver(notificationReceiver,new IntentFilter(Najva.ACTION_NOTIFICATION_RECEIVED));
        context.registerReceiver(clickReceiver,new IntentFilter(Najva.ACTION_CLICK_RECEIVED));

        return true;
    }

    /**
     * calls method on dart code when new JSON data has been received
     *
     * @param data is JSONObject has received from najva service
     */
    private void onJSONDataReceived(String data) {
        channel.invokeMethod(NEW_JSON_DATA, data);
    }

    @Override
    public void najvaUserSubscribed(String token) {
        channel.invokeMethod(NEW_USER_SUBSCRIBED, token);
    }

    private String getSubscribedToken() {
        return Najva.getSubscribedToken(context);
    }

    @Override
    public void onClicked(Map<String, String> data) {
        channel.invokeMethod(NEW_NOTIFICATION_CLICKED,data);
    }

    @Override
    public void onReceive(Map<String, String> data) {
        channel.invokeMethod(NEW_NOTIFICATION_RECEIVED,data);

    }


}

==> najvaflutter-1.2.2.tar.gz: android/src/main/java/com/najva/najvaflutter/NajvaflutterPlugin.java <==
package com.najva.najvaflutter;

import android.content.Context;
import android.content.IntentFilter;

import com.najva.sdk.Najva;
import com.najva.sdk.NajvaJsonDataListener;
import com.najva.sdk.UserSubscriptionListener;


import java.util.Map;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry;

/**
 * NajvaflutterpluginPlugin
 * created by shayan
 * flutter plugin for implement all features of najva android sdk in flutter
 **/
public class NajvaflutterPlugin implements MethodCallHandler,
        NajvaPluginUserHandler.INajvaPluginUserHandler,
        NajvaNotificationReceiver.OnNotificationReceiveListener,
        NajvaNotificationClickReceiver.OnNotificationClickListener{

    /**
     * final variables used for method names
     */
    private static final String INIT = "init";
    private static final String GET_SUBSCRIBED_TOKEN = "get_subscribed_token";

    /**
     * final variables for dart method names
     */
    private static final String NEW_JSON_DATA = "onNewJSONData";
    private static final String NEW_USER_SUBSCRIBED = " onUserSubscribed";
    private static final String NEW_NOTIFICATION_RECEIVED = "onNotificationReceived";
    private static final String NEW_NOTIFICATION_CLICKED = "onNotificationClicked";

    /**
     * Plugin registration.
     */
    public static void registerWith(PluginRegistry.Registrar registrar) {
        final MethodChannel channel = new MethodChannel(registrar.messenger(), "najvaFlutterplugin");
        channel.setMethodCallHandler(new NajvaflutterPlugin(channel,registrar.context()));

    }

    /* class implementation */

    private MethodChannel channel;
    private Context context;


    private NajvaflutterPlugin(MethodChannel channel, Context context) {
        this.channel = channel;
        this.context = context;
    }


    @Override
    public void onMethodCall(MethodCall call, Result result) {
        switch (call.method) {
            case INIT:
                result.success(init());
                break;
            case GET_SUBSCRIBED_TOKEN:
                result.success(getSubscribedToken());
                break;
            default:
                result.notImplemented();
                break;
        }
    }

    private void handleUsersToken() {
        initUserHandler(new NajvaPluginUserHandler(this));
    }

    private void handleJSONNotification() {
        Najva.setNajvaJsonDataListener(new NajvaJsonDataListener() {
            @Override
            public void onReceiveJson(String s) {
                onJSONDataReceived(s);
            }
        });
    }

    private void initUserHandler(UserSubscriptionListener handler) {
        Najva.setUserSubscriptionListener(handler);
    }

    private boolean init() {

        Najva.initialize(context);
        handleJSONNotification();
        handleUsersToken();
        NajvaNotificationReceiver notificationReceiver = new NajvaNotificationReceiver(this);
        NajvaNotificationClickReceiver clickReceiver = new NajvaNotificationClickReceiver(this);
        context.registerReceiver(notificationReceiver,new IntentFilter(Najva.ACTION_NOTIFICATION_RECEIVED));
        context.registerReceiver(clickReceiver,new IntentFilter(Najva.ACTION_CLICK_RECEIVED));

        return true;
    }

    /**
     * calls method on dart code when new JSON data has been received
     *
     * @param data is JSONObject has received from najva service
     */
    private void onJSONDataReceived(String data) {
        channel.invokeMethod(NEW_JSON_DATA, data);
    }

    @Override
    public void najvaUserSubscribed(String token) {
        channel.invokeMethod(NEW_USER_SUBSCRIBED, token);
    }

    private String getSubscribedToken() {
        return Najva.getSubscribedToken(context);
    }

    @Override
    public void onClicked(Map<String, String> data) {
        channel.invokeMethod(NEW_NOTIFICATION_CLICKED,data);
    }

    @Override
    public void onReceive(Map<String, String> data) {
        channel.invokeMethod(NEW_NOTIFICATION_RECEIVED,data);

    }


}
